==> kubernetes-model-autoscaling-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2/MetricSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class MetricSpecFluentImpl<A extends MetricSpecFluent<A>> extends BaseFluent<A> implements MetricSpecFluent<A>{
  public MetricSpecFluentImpl() {
  }
  public MetricSpecFluentImpl(MetricSpec instance) {
    this.withContainerResource(instance.getContainerResource()); 
    this.withExternal(instance.getExternal()); 
    this.withObject(instance.getObject()); 
    this.withPods(instance.getPods()); 
    this.withResource(instance.getResource()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ContainerResourceMetricSourceBuilder containerResource;
  private ExternalMetricSourceBuilder external;
  private ObjectMetricSourceBuilder object;
  private PodsMetricSourceBuilder pods;
  private ResourceMetricSourceBuilder resource;
  private String type;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildContainerResource instead.
   * @return The buildable object.
   */
  @Deprecated
  public ContainerResourceMetricSource getContainerResource() {
    return this.containerResource!=null ?this.containerResource.build():null;
  }
  public ContainerResourceMetricSource buildContainerResource() {
    return this.containerResource!=null ?this.containerResource.build():null;
  }
  public A withContainerResource(ContainerResourceMetricSource containerResource) {
    _visitables.get("containerResource").remove(this.containerResource);
    if (containerResource!=null){ this.containerResource= new ContainerResourceMetricSourceBuilder(containerResource); _visitables.get("containerResource").add(this.containerResource);} else { this.containerResource = null; _visitables.get("containerResource").remove(this.containerResource); } return (A) this;
  }
  public Boolean hasContainerResource() {
    return this.containerResource != null;
  }
  public MetricSpecFluent.ContainerResourceNested<A> withNewContainerResource() {
    return new MetricSpecFluentImpl.ContainerResourceNestedImpl();
  }
  public MetricSpecFluent.ContainerResourceNested<A> withNewContainerResourceLike(ContainerResourceMetricSource item) {
    return new MetricSpecFluentImpl.ContainerResourceNestedImpl(item);
  }
  public MetricSpecFluent.ContainerResourceNested<A> editContainerResource() {
    return withNewContainerResourceLike(getContainerResource());
  }
  public MetricSpecFluent.ContainerResourceNested<A> editOrNewContainerResource() {
    return withNewContainerResourceLike(getContainerResource() != null ? getContainerResource(): new ContainerResourceMetricSourceBuilder().build());
  }
  public MetricSpecFluent.ContainerResourceNested<A> editOrNewContainerResourceLike(ContainerResourceMetricSource item) {
    return withNewContainerResourceLike(getContainerResource() != null ? getContainerResource(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildExternal instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExternalMetricSource getExternal() {
    return this.external!=null ?this.external.build():null;
  }
  public ExternalMetricSource buildExternal() {
    return this.external!=null ?this.external.build():null;
  }
  public A withExternal(ExternalMetricSource external) {
    _visitables.get("external").remove(this.external);
    if (external!=null){ this.external= new ExternalMetricSourceBuilder(external); _visitables.get("external").add(this.external);} else { this.external = null; _visitables.get("external").remove(this.external); } return (A) this;
  }
  public Boolean hasExternal() {
    return this.external != null;
  }
  public MetricSpecFluent.ExternalNested<A> withNewExternal() {
    return new MetricSpecFluentImpl.ExternalNestedImpl();
  }
  public MetricSpecFluent.ExternalNested<A> withNewExternalLike(ExternalMetricSource item) {
    return new MetricSpecFluentImpl.ExternalNestedImpl(item);
  }
  public MetricSpecFluent.ExternalNested<A> editExternal() {
    return withNewExternalLike(getExternal());
  }
  public MetricSpecFluent.ExternalNested<A> editOrNewExternal() {
    return withNewExternalLike(getExternal() != null ? getExternal(): new ExternalMetricSourceBuilder().build());
  }
  public MetricSpecFluent.ExternalNested<A> editOrNewExternalLike(ExternalMetricSource item) {
    return withNewExternalLike(getExternal() != null ? getExternal(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildObject instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMetricSource getObject() {
    return this.object!=null ?this.object.build():null;
  }
  public ObjectMetricSource buildObject() {
    return this.object!=null ?this.object.build():null;
  }
  public A withObject(ObjectMetricSource object) {
    _visitables.get("object").remove(this.object);
    if (object!=null){ this.object= new ObjectMetricSourceBuilder(object); _visitables.get("object").add(this.object);} else { this.object = null; _visitables.get("object").remove(this.object); } return (A) this;
  }
  public Boolean hasObject() {
    return this.object != null;
  }
  public MetricSpecFluent.ObjectNested<A> withNewObject() {
    return new MetricSpecFluentImpl.ObjectNestedImpl();
  }
  public MetricSpecFluent.ObjectNested<A> withNewObjectLike(ObjectMetricSource item) {
    return new MetricSpecFluentImpl.ObjectNestedImpl(item);
  }
  public MetricSpecFluent.ObjectNested<A> editObject() {
    return withNewObjectLike(getObject());
  }
  public MetricSpecFluent.ObjectNested<A> editOrNewObject() {
    return withNewObjectLike(getObject() != null ? getObject(): new ObjectMetricSourceBuilder().build());
  }
  public MetricSpecFluent.ObjectNested<A> editOrNewObjectLike(ObjectMetricSource item) {
    return withNewObjectLike(getObject() != null ? getObject(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPods instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodsMetricSource getPods() {
    return this.pods!=null ?this.pods.build():null;
  }
  public PodsMetricSource buildPods() {
    return this.pods!=null ?this.pods.build():null;
  }
  public A withPods(PodsMetricSource pods) {
    _visitables.get("pods").remove(this.pods);
    if (pods!=null){ this.pods= new PodsMetricSourceBuilder(pods); _visitables.get("pods").add(this.pods);} else { this.pods = null; _visitables.get("pods").remove(this.pods); } return (A) this;
  }
  public Boolean hasPods() {
    return this.pods != null;
  }
  public MetricSpecFluent.PodsNested<A> withNewPods() {
    return new MetricSpecFluentImpl.PodsNestedImpl();
  }
  public MetricSpecFluent.PodsNested<A> withNewPodsLike(PodsMetricSource item) {
    return new MetricSpecFluentImpl.PodsNestedImpl(item);
  }
  public MetricSpecFluent.PodsNested<A> editPods() {
    return withNewPodsLike(getPods());
  }
  public MetricSpecFluent.PodsNested<A> editOrNewPods() {
    return withNewPodsLike(getPods() != null ? getPods(): new PodsMetricSourceBuilder().build());
  }
  public MetricSpecFluent.PodsNested<A> editOrNewPodsLike(PodsMetricSource item) {
    return withNewPodsLike(getPods() != null ? getPods(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildResource instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceMetricSource getResource() {
    return this.resource!=null ?this.resource.build():null;
  }
  public ResourceMetricSource buildResource() {
    return this.resource!=null ?this.resource.build():null;
  }
  public A withResource(ResourceMetricSource resource) {
    _visitables.get("resource").remove(this.resource);
    if (resource!=null){ this.resource= new ResourceMetricSourceBuilder(resource); _visitables.get("resource").add(this.resource);} else { this.resource = null; _visitables.get("resource").remove(this.resource); } return (A) this;
  }
  public Boolean hasResource() {
    return this.resource != null;
  }
  public MetricSpecFluent.ResourceNested<A> withNewResource() {
    return new MetricSpecFluentImpl.ResourceNestedImpl();
  }
  public MetricSpecFluent.ResourceNested<A> withNewResourceLike(ResourceMetricSource item) {
    return new MetricSpecFluentImpl.ResourceNestedImpl(item);
  }
  public MetricSpecFluent.ResourceNested<A> editResource() {
    return withNewResourceLike(getResource());
  }
  public MetricSpecFluent.ResourceNested<A> editOrNewResource() {
    return withNewResourceLike(getResource() != null ? getResource(): new ResourceMetricSourceBuilder().build());
  }
  public MetricSpecFluent.ResourceNested<A> editOrNewResourceLike(ResourceMetricSource item) {
    return withNewResourceLike(getResource() != null ? getResource(): item);
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    MetricSpecFluentImpl that = (MetricSpecFluentImpl) o;
    if (containerResource != null ? !containerResource.equals(that.containerResource) :that.containerResource != null) return false;
    if (external != null ? !external.equals(that.external) :that.external != null) return false;
    if (object != null ? !object.equals(that.object) :that.object != null) return false;
    if (pods != null ? !pods.equals(that.pods) :that.pods != null) return false;
    if (resource != null ? !resource.equals(that.resource) :that.resource != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(containerResource,  external,  object,  pods,  resource,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (containerResource != null) { sb.append("containerResource:"); sb.append(containerResource + ","); }
    if (external != null) { sb.append("external:"); sb.append(external + ","); }
    if (object != null) { sb.append("object:"); sb.append(object + ","); }
    if (pods != null) { sb.append("pods:"); sb.append(pods + ","); }
    if (resource != null) { sb.append("resource:"); sb.append(resource + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ContainerResourceNestedImpl<N> extends ContainerResourceMetricSourceFluentImpl<MetricSpecFluent.ContainerResourceNested<N>> implements MetricSpecFluent.ContainerResourceNested<N>,Nested<N>{
    ContainerResourceNestedImpl(ContainerResourceMetricSource item) {
      this.builder = new ContainerResourceMetricSourceBuilder(this, item);
    }
    ContainerResourceNestedImpl() {
      this.builder = new ContainerResourceMetricSourceBuilder(this);
    }
    ContainerResourceMetricSourceBuilder builder;
    public N and() {
      return (N) MetricSpecFluentImpl.this.withContainerResource(builder.build());
    }
    public N endContainerResource() {
      return and();
    }
    
  }
  class ExternalNestedImpl<N> extends ExternalMetricSourceFluentImpl<MetricSpecFluent.ExternalNested<N>> implements MetricSpecFluent.ExternalNested<N>,Nested<N>{
    ExternalNestedImpl(ExternalMetricSource item) {
      this.builder = new ExternalMetricSourceBuilder(this, item);
    }
    ExternalNestedImpl() {
      this.builder = new ExternalMetricSourceBuilder(this);
    }
    ExternalMetricSourceBuilder builder;
    public N and() {
      return (N) MetricSpecFluentImpl.this.withExternal(builder.build());
    }
    public N endExternal() {
      return and();
    }
    
  }
  class ObjectNestedImpl<N> extends ObjectMetricSourceFluentImpl<MetricSpecFluent.ObjectNested<N>> implements MetricSpecFluent.ObjectNested<N>,Nested<N>{
    ObjectNestedImpl(ObjectMetricSource item) {
      this.builder = new ObjectMetricSourceBuilder(this, item);
    }
    ObjectNestedImpl() {
      this.builder = new ObjectMetricSourceBuilder(this);
    }
    ObjectMetricSourceBuilder builder;
    public N and() {
      return (N) MetricSpecFluentImpl.this.withObject(builder.build());
    }
    public N endObject() {
      return and();
    }
    
  }
  class PodsNestedImpl<N> extends PodsMetricSourceFluentImpl<MetricSpecFluent.PodsNested<N>> implements MetricSpecFluent.PodsNested<N>,Nested<N>{
    PodsNestedImpl(PodsMetricSource item) {
      this.builder = new PodsMetricSourceBuilder(this, item);
    }
    PodsNestedImpl() {
      this.builder = new PodsMetricSourceBuilder(this);
    }
    PodsMetricSourceBuilder builder;
    public N and() {
      return (N) MetricSpecFluentImpl.this.withPods(builder.build());
    }
    public N endPods() {
      return and();
    }
    
  }
  class ResourceNestedImpl<N> extends ResourceMetricSourceFluentImpl<MetricSpecFluent.ResourceNested<N>> implements MetricSpecFluent.ResourceNested<N>,Nested<N>{
    ResourceNestedImpl(ResourceMetricSource item) {
      this.builder = new ResourceMetricSourceBuilder(this, item);
    }
    ResourceNestedImpl() {
      this.builder = new ResourceMetricSourceBuilder(this);
    }
    ResourceMetricSourceBuilder builder;
    public N and() {
      return (N) MetricSpecFluentImpl.this.withResource(builder.build());
    }
    public N endResource() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-autoscaling-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2/MetricSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class MetricSpecFluentImpl<A extends MetricSpecFluent<A>> extends BaseFluent<A> implements MetricSpecFluent<A>{
  public MetricSpecFluentImpl() {
  }
  public MetricSpecFluentImpl(MetricSpec instance) {
    if (instance != null) {
      this.withContainerResource(instance.getContainerResource());
      this.withExternal(instance.getExternal());
      this.withObject(instance.getObject());
      this.withPods(instance.getPods());
      this.withResource(instance.getResource());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ContainerResourceMetricSourceBuilder containerResource;
  private ExternalMetricSourceBuilder external;
  private ObjectMetricSourceBuilder object;
  private PodsMetricSourceBuilder pods;
  private ResourceMetricSourceBuilder resource;
  private String type;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildContainerResource instead.
   * @return The buildable object.
   */
  @Deprecated
  public ContainerResourceMetricSource getContainerResource() {
    return this.containerResource!=null ?this.containerResource.build():null;
  }
  public ContainerResourceMetricSource buildContainerResource() {
    return this.containerResource!=null ?this.containerResource.build():null;
  }
  public A withContainerResource(ContainerResourceMetricSource containerResource) {
    _visitables.get("containerResource").remove(this.containerResource);
    if (containerResource!=null){ this.containerResource= new ContainerResourceMetricSourceBuilder(containerResource); _visitables.get("containerResource").add(this.containerResource);} else { this.containerResource = null; _visitables.get("containerResource").remove(this.containerResource); } return (A) this;
  }
  public Boolean hasContainerResource() {
    return this.containerResource != null;
  }
  public MetricSpecFluentImpl.ContainerResourceNested<A> withNewContainerResource() {
    return new MetricSpecFluentImpl.ContainerResourceNestedImpl();
  }
  public MetricSpecFluentImpl.ContainerResourceNested<A> withNewContainerResourceLike(ContainerResourceMetricSource item) {
    return new MetricSpecFluentImpl.ContainerResourceNestedImpl(item);
  }
  public MetricSpecFluentImpl.ContainerResourceNested<A> editContainerResource() {
    return withNewContainerResourceLike(getContainerResource());
  }
  public MetricSpecFluentImpl.ContainerResourceNested<A> editOrNewContainerResource() {
    return withNewContainerResourceLike(getContainerResource() != null ? getContainerResource(): new ContainerResourceMetricSourceBuilder().build());
  }
  public MetricSpecFluentImpl.ContainerResourceNested<A> editOrNewContainerResourceLike(ContainerResourceMetricSource item) {
    return withNewContainerResourceLike(getContainerResource() != null ? getContainerResource(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildExternal instead.
   * @return The buildable object.
   */
  @Deprecated
  public ExternalMetricSource getExternal() {
    return this.external!=null ?this.external.build():null;
  }
  public ExternalMetricSource buildExternal() {
    return this.external!=null ?this.external.build():null;
  }
  public A withExternal(ExternalMetricSource external) {
    _visitables.get("external").remove(this.external);
    if (external!=null){ this.external= new ExternalMetricSourceBuilder(external); _visitables.get("external").add(this.external);} else { this.external = null; _visitables.get("external").remove(this.external); } return (A) this;
  }
  public Boolean hasExternal() {
    return this.external != null;
  }
  public MetricSpecFluentImpl.ExternalNested<A> withNewExternal() {
    return new MetricSpecFluentImpl.ExternalNestedImpl();
  }
  public MetricSpecFluentImpl.ExternalNested<A> withNewExternalLike(ExternalMetricSource item) {
    return new MetricSpecFluentImpl.ExternalNestedImpl(item);
  }
  public MetricSpecFluentImpl.ExternalNested<A> editExternal() {
    return withNewExternalLike(getExternal());
  }
  public MetricSpecFluentImpl.ExternalNested<A> editOrNewExternal() {
    return withNewExternalLike(getExternal() != null ? getExternal(): new ExternalMetricSourceBuilder().build());
  }
  public MetricSpecFluentImpl.ExternalNested<A> editOrNewExternalLike(ExternalMetricSource item) {
    return withNewExternalLike(getExternal() != null ? getExternal(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildObject instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMetricSource getObject() {
    return this.object!=null ?this.object.build():null;
  }
  public ObjectMetricSource buildObject() {
    return this.object!=null ?this.object.build():null;
  }
  public A withObject(ObjectMetricSource object) {
    _visitables.get("object").remove(this.object);
    if (object!=null){ this.object= new ObjectMetricSourceBuilder(object); _visitables.get("object").add(this.object);} else { this.object = null; _visitables.get("object").remove(this.object); } return (A) this;
  }
  public Boolean hasObject() {
    return this.object != null;
  }
  public MetricSpecFluentImpl.ObjectNested<A> withNewObject() {
    return new MetricSpecFluentImpl.ObjectNestedImpl();
  }
  public MetricSpecFluentImpl.ObjectNested<A> withNewObjectLike(ObjectMetricSource item) {
    return new MetricSpecFluentImpl.ObjectNestedImpl(item);
  }
  public MetricSpecFluentImpl.ObjectNested<A> editObject() {
    return withNewObjectLike(getObject());
  }
  public MetricSpecFluentImpl.ObjectNested<A> editOrNewObject() {
    return withNewObjectLike(getObject() != null ? getObject(): new ObjectMetricSourceBuilder().build());
  }
  public MetricSpecFluentImpl.ObjectNested<A> editOrNewObjectLike(ObjectMetricSource item) {
    return withNewObjectLike(getObject() != null ? getObject(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPods instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodsMetricSource getPods() {
    return this.pods!=null ?this.pods.build():null;
  }
  public PodsMetricSource buildPods() {
    return this.pods!=null ?this.pods.build():null;
  }
  public A withPods(PodsMetricSource pods) {
    _visitables.get("pods").remove(this.pods);
    if (pods!=null){ this.pods= new PodsMetricSourceBuilder(pods); _visitables.get("pods").add(this.pods);} else { this.pods = null; _visitables.get("pods").remove(this.pods); } return (A) this;
  }
  public Boolean hasPods() {
    return this.pods != null;
  }
  public MetricSpecFluentImpl.PodsNested<A> withNewPods() {
    return new MetricSpecFluentImpl.PodsNestedImpl();
  }
  public MetricSpecFluentImpl.PodsNested<A> withNewPodsLike(PodsMetricSource item) {
    return new MetricSpecFluentImpl.PodsNestedImpl(item);
  }
  public MetricSpecFluentImpl.PodsNested<A> editPods() {
    return withNewPodsLike(getPods());
  }
  public MetricSpecFluentImpl.PodsNested<A> editOrNewPods() {
    return withNewPodsLike(getPods() != null ? getPods(): new PodsMetricSourceBuilder().build());
  }
  public MetricSpecFluentImpl.PodsNested<A> editOrNewPodsLike(PodsMetricSource item) {
    return withNewPodsLike(getPods() != null ? getPods(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildResource instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceMetricSource getResource() {
    return this.resource!=null ?this.resource.build():null;
  }
  public ResourceMetricSource buildResource() {
    return this.resource!=null ?this.resource.build():null;
  }
  public A withResource(ResourceMetricSource resource) {
    _visitables.get("resource").remove(this.resource);
    if (resource!=null){ this.resource= new ResourceMetricSourceBuilder(resource); _visitables.get("resource").add(this.resource);} else { this.resource = null; _visitables.get("resource").remove(this.resource); } return (A) this;
  }
  public Boolean hasResource() {
    return this.resource != null;
  }
  public MetricSpecFluentImpl.ResourceNested<A> withNewResource() {
    return new MetricSpecFluentImpl.ResourceNestedImpl();
  }
  public MetricSpecFluentImpl.ResourceNested<A> withNewResourceLike(ResourceMetricSource item) {
    return new MetricSpecFluentImpl.ResourceNestedImpl(item);
  }
  public MetricSpecFluentImpl.ResourceNested<A> editResource() {
    return withNewResourceLike(getResource());
  }
  public MetricSpecFluentImpl.ResourceNested<A> editOrNewResource() {
    return withNewResourceLike(getResource() != null ? getResource(): new ResourceMetricSourceBuilder().build());
  }
  public MetricSpecFluentImpl.ResourceNested<A> editOrNewResourceLike(ResourceMetricSource item) {
    return withNewResourceLike(getResource() != null ? getResource(): item);
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MetricSpecFluentImpl that = (MetricSpecFluentImpl) o;
    if (!java.util.Objects.equals(containerResource, that.containerResource)) return false;

    if (!java.util.Objects.equals(external, that.external)) return false;

    if (!java.util.Objects.equals(object, that.object)) return false;

    if (!java.util.Objects.equals(pods, that.pods)) return false;

    if (!java.util.Objects.equals(resource, that.resource)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(containerResource,  external,  object,  pods,  resource,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (containerResource != null) { sb.append("containerResource:"); sb.append(containerResource + ","); }
    if (external != null) { sb.append("external:"); sb.append(external + ","); }
    if (object != null) { sb.append("object:"); sb.append(object + ","); }
    if (pods != null) { sb.append("pods:"); sb.append(pods + ","); }
    if (resource != null) { sb.append("resource:"); sb.append(resource + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ContainerResourceNestedImpl<N> extends ContainerResourceMetricSourceFluentImpl<MetricSpecFluentImpl.ContainerResourceNested<N>> implements MetricSpecFluentImpl.ContainerResourceNested<N>,Nested<N>{
    ContainerResourceNestedImpl(ContainerResourceMetricSource item) {
      this.builder = new ContainerResourceMetricSourceBuilder(this, item);
    }
    ContainerResourceNestedImpl() {
      this.builder = new ContainerResourceMetricSourceBuilder(this);
    }
    ContainerResourceMetricSourceBuilder builder;
    public N and() {
      return (N) MetricSpecFluentImpl.this.withContainerResource(builder.build());
    }
    public N endContainerResource() {
      return and();
    }
    
  }
  class ExternalNestedImpl<N> extends ExternalMetricSourceFluentImpl<MetricSpecFluentImpl.ExternalNested<N>> implements MetricSpecFluentImpl.ExternalNested<N>,Nested<N>{
    ExternalNestedImpl(ExternalMetricSource item) {
      this.builder = new ExternalMetricSourceBuilder(this, item);
    }
    ExternalNestedImpl() {
      this.builder = new ExternalMetricSourceBuilder(this);
    }
    ExternalMetricSourceBuilder builder;
    public N and() {
      return (N) MetricSpecFluentImpl.this.withExternal(builder.build());
    }
    public N endExternal() {
      return and();
    }
    
  }
  class ObjectNestedImpl<N> extends ObjectMetricSourceFluentImpl<MetricSpecFluentImpl.ObjectNested<N>> implements MetricSpecFluentImpl.ObjectNested<N>,Nested<N>{
    ObjectNestedImpl(ObjectMetricSource item) {
      this.builder = new ObjectMetricSourceBuilder(this, item);
    }
    ObjectNestedImpl() {
      this.builder = new ObjectMetricSourceBuilder(this);
    }
    ObjectMetricSourceBuilder builder;
    public N and() {
      return (N) MetricSpecFluentImpl.this.withObject(builder.build());
    }
    public N endObject() {
      return and();
    }
    
  }
  class PodsNestedImpl<N> extends PodsMetricSourceFluentImpl<MetricSpecFluentImpl.PodsNested<N>> implements MetricSpecFluentImpl.PodsNested<N>,Nested<N>{
    PodsNestedImpl(PodsMetricSource item) {
      this.builder = new PodsMetricSourceBuilder(this, item);
    }
    PodsNestedImpl() {
      this.builder = new PodsMetricSourceBuilder(this);
    }
    PodsMetricSourceBuilder builder;
    public N and() {
      return (N) MetricSpecFluentImpl.this.withPods(builder.build());
    }
    public N endPods() {
      return and();
    }
    
  }
  class ResourceNestedImpl<N> extends ResourceMetricSourceFluentImpl<MetricSpecFluentImpl.ResourceNested<N>> implements MetricSpecFluentImpl.ResourceNested<N>,Nested<N>{
    ResourceNestedImpl(ResourceMetricSource item) {
      this.builder = new ResourceMetricSourceBuilder(this, item);
    }
    ResourceNestedImpl() {
      this.builder = new ResourceMetricSourceBuilder(this);
    }
    ResourceMetricSourceBuilder builder;
    public N and() {
      return (N) MetricSpecFluentImpl.this.withResource(builder.build());
    }
    public N endResource() {
      return and();
    }
    
  }
  
}
